# BijoyToUnicode

It is a utility to convert bijoy encoded text to unicode.

## Usage

```python
from bijoytounicode import bijoy2unicode
TEST_TEXT = "‡Kv‡bv †Kv‡bv w`b, AvKvk‡Rvov †gN K‡i, Kv‡R gb e‡m bv| †W‡¯‹i mvg‡bi Rvbvjvi c`©v Zz‡j w`B| w¯Œ‡b ZvKvB, †`wL bv, `‚ieZ©x AvKvk I Bgvi‡Z wKQz †LvuR _v‡K| Ggb me w`‡bi bvg †KvgjMvÜvi|"
bijoy2unicode(TEST_TEXT)
```
